<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}
?>
<div class="vc_resources-tab changelog">
	<div class="feature-section vc_row">
		<div class="vc_col-xs-6">
			<h3><?php esc_html_e( 'Resources', 'js_composer' ); ?></h3>

			<p><?php esc_html_e( 'There are several resources available to WPBakery Page Builder users to help you to get around plugin:', 'js_composer' ); ?></p>
			<ul>
				<li>
					<a href="https://wpbakery.com/?utm_campaign=VCplugin&amp;utm_source=vc_user&amp;utm_medium=welcome_page" target="_blank"><?php esc_html_e( 'Official website', 'js_composer' ); ?></a>
				</li>
				<li><a href="https://kb.wpbakery.com" target="_blank"><?php esc_html_e( 'Official Knowledge Base', 'js_composer' ); ?></a></li>
				<li><a href="https://wpbakery.com/video-academy/" target="_blank"><?php esc_html_e( 'Video Academy', 'js_composer' ); ?></a></li>
				<li><a href="https://support.wpbakery.com" target="_blank"><?php esc_html_e( 'Official support', 'js_composer' ); ?></a></li>
				<li><a href="https://facebook.com/wpbakery" target="_blank"><?php esc_html_e( 'Facebook page', 'js_composer' ); ?></a></li>
				<li><a href="https://twitter.com/wpbakery" target="_blank"><?php esc_html_e( 'Twitter account', 'js_composer' ); ?></a></li>
			</ul>
		</div>

		<div class="vc_col-xs-6">
			<h3><?php esc_html_e( 'Official Support', 'js_composer' ); ?></h3>

			<p><?php printf( esc_html__( 'To get your support related question answered in the fastest timing, please head over to our %ssupport page%s and open Support ticket. To open a support ticket you should have a valid support subscription in case if your support has expired you can %spurchase support extension%s on support.wpbakery.com.', 'js_composer' ), '<a href="https://support.wpbakery.com" target="_blank">', '</a>', '<a href="https://support.wpbakery.com" target="_blank">', '</a>' ); ?></p>

			<p><?php printf( esc_html__( 'Before applying for support please make sure you understand the rules of support and go through all steps described and listed in %sSupport Policy%s in order to get your issues solved as soon as possible.', 'js_composer' ), '<a href="https://go.wpbakery.com/support-policy" target="_blank">', '</a>' ); ?></p>
		</div>
	</div>
</div>
